Module: ReductoAI
- Defined in:
- lib/reducto_ai.rb,
lib/reducto_ai/client.rb,
lib/reducto_ai/config.rb,
lib/reducto_ai/engine.rb,
lib/reducto_ai/errors.rb,
lib/reducto_ai/version.rb,
lib/reducto_ai/job_status.rb,
lib/reducto_ai/resources/edit.rb,
lib/reducto_ai/resources/jobs.rb,
lib/reducto_ai/webhooks/event.rb,
lib/reducto_ai/resources/parse.rb,
lib/reducto_ai/resources/split.rb,
lib/reducto_ai/resources/extract.rb,
lib/reducto_ai/webhooks/verifier.rb,
lib/reducto_ai/resources/pipeline.rb,
lib/reducto_ai/rails/request_verifier.rb,
lib/reducto_ai/resources/async_payload.rb
Overview
Main namespace for the ReductoAI gem.
Provides global configuration management for the Reducto API client. Use ReductoAI.configure to set API credentials and options, then create a Client instance to interact with the Reducto document intelligence API.
Defined Under Namespace
Modules: JobStatus, Rails, Resources, Webhooks Classes: AuthenticationError, Client, ClientError, Config, Engine, Error, JobFailedError, JobTimeoutError, NetworkError, RateLimitError, ServerError, WebhookVerificationError
Constant Summary collapse
- VERSION =
Gem version
"0.2.2"
Class Method Summary collapse
-
.config ⇒ Config
Returns the global configuration instance.
-
.configure {|config| ... } ⇒ void
Configures the ReductoAI client globally.
-
.reset_configuration! ⇒ void
Resets the global configuration to nil.
Class Method Details
.config ⇒ Config
Returns the global configuration instance.
38 39 40 |
# File 'lib/reducto_ai.rb', line 38 def config @config ||= Config.new end |
.configure {|config| ... } ⇒ void
This method returns an undefined value.
Configures the ReductoAI client globally.
54 55 56 |
# File 'lib/reducto_ai.rb', line 54 def configure yield(config) end |
.reset_configuration! ⇒ void
This method returns an undefined value.
Resets the global configuration to nil.
Primarily used for testing to ensure a clean configuration state.
63 64 65 |
# File 'lib/reducto_ai.rb', line 63 def reset_configuration! @config = nil end |